# Changelog

## v1.1.1 (Mar, 26th 2016)

Exclude tests from installation

## v1.1.0 (Dec, 5th 2016)

Added command line client

## v1.0.0 (Oct, 19th 2016)

Stable release

## v0.2.0 (Dec, 15th 2015)

Changed syntax

## v0.1.0 (Oct, 19th 2015)

First release